@@ -12,42 +12,44 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement',
+ 'BASECFLAGS': '-fno-strict-aliasing',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python3.4',
  'BLDLIBRARY': '-L. -lpython3.4m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+              '-L/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'powerpc-unknown-openbsd5.6',
+ 'BUILD_GNU_TYPE': 'mips64-unknown-openbsd5.7',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
-           '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
+ 'CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 '
+           '-pipe',
  'CFLAGSFORSHARED': '-fPIC',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.4.1/Python-3.4.1' "
+                "'--srcdir=/usr/obj/ports/Python-3.4.2/Python-3.4.2' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-cxx_main' '--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
                 "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
-                "'--localstatedir=/var' '--disable-silent-rules' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
-                "'CPPFLAGS=-I/usr/local/include'",
+                "'--localstatedir=/var' '--disable-silent-rules' "
+                "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' "
+                "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.4m',
  'COREPYTHONPATH': ':plat-openbsd5',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.4.1/Python-3.4.1/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.4.1/Python-3.4.1/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.4.2/Python-3.4.2/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.4.2/Python-3.4.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
@@ -86,11 +88,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
  'GRAMMAR_INPUT': './Grammar/Grammar',
- 'HAVE_ACCEPT4': 0,
+ 'HAVE_ACCEPT4': 1,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 0,
+ 'HAVE_ALIGNED_REQUIRED': 1,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -137,7 +139,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
- 'HAVE_DUP3': 0,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 1,
  'HAVE_EPOLL': 0,
@@ -178,7 +180,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETGROUPLIST': 1,
@@ -209,7 +211,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
- 'HAVE_HTOLE64': 0,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 1,
  'HAVE_IF_NAMEINDEX': 1,
@@ -225,7 +227,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -275,7 +277,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
- 'HAVE_PIPE2': 0,
+ 'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
@@ -454,27 +456,27 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'powerpc-unknown-openbsd5.6',
+ 'HOST_GNU_TYPE': 'mips64-unknown-openbsd5.7',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.4m '
                    '/usr/local/include/python3.4m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.4m',
- 'INSTALL': '/usr/bin/install -c -o root -g bin',
- 'INSTALL_DATA': 'install -c -o root -g bin -m 444',
- 'INSTALL_PROGRAM': 'install -c -s -o root -g bin -m 555',
- 'INSTALL_SCRIPT': 'install -c -o root -g bin -m 555',
- 'INSTALL_SHARED': '/usr/bin/install -c -o root -g bin -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-3.4.2/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.4.2/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.4.2/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.4.2/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.4.2/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.4m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.4m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+             '-L/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'LDVERSION': '3.4m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.4',
@@ -529,7 +531,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
- 'OPT': '-DNDEBUG -O2 -pipe  -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -562,16 +564,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
-              '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe',
- 'PY_CORE_CFLAGS': '-fno-strict-aliasing -Werror=declaration-after-statement '
-                   '-DNDEBUG -O2 -pipe  -fPIC -O2 -pipe -O2 -pipe -I. '
+ 'PY_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 '
+              '-pipe',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-fno-strict-aliasing -DNDEBUG -O2 -pipe   -fPIC -O2 '
+                   '-pipe -O2 -pipe -Werror=declaration-after-statement -I. '
                    '-IInclude -I./Include -I/usr/local/include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -580,7 +583,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -594,17 +597,17 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-34m',
@@ -622,10 +625,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.2/Python-3.4.2 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.1/Python-3.4.1 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.4.2/Python-3.4.2 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
@@ -636,7 +639,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_INLINE': 1,
- 'VA_LIST_IS_ARRAY': 1,
+ 'VA_LIST_IS_ARRAY': 0,
  'VERSION': '3.4',
  'WANT_SIGFPE_HANDLER': 1,
  'WINDOW_HAS_FLAGS': 1,
@@ -650,8 +653,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.4.1/Python-3.4.1',
- 'abs_srcdir': '/usr/obj/ports/Python-3.4.1/Python-3.4.1',
+ 'abs_builddir': '/usr/obj/ports/Python-3.4.2/Python-3.4.2',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.4.2/Python-3.4.2',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
